@@ -1,9 +1,11 @@
 import re
 from functools import partial
 from pathlib import Path
-from typing import Optional, Pattern, Set, Tuple
+from typing import Any, Dict, Mapping, Optional, Pattern, Set, Tuple, Union
 
-import click
+import click  # lgtm [py/import-and-import-from]
+
+from curlylint.rule_param import RULE
 
 from . import __version__
 from .config import (
@@ -12,7 +14,7 @@ from .config import (
     get_gitignore,
     read_pyproject_toml,
 )
-from .lint import lint
+from .lint import lint, lint_one
 from .report import Report
 
 out = partial(click.secho, bold=True, err=True)
@@ -61,6 +63,12 @@ def path_empty(
     is_flag=True,
     help="Don’t lint, check for syntax errors and exit.",
 )
+@click.option(
+    "--print-config",
+    is_flag=True,
+    help="Print the configuration for the given file.",
+    is_eager=True,
+)
 @click.option(
     "-f",
     "--format",
@@ -69,6 +77,17 @@ def path_empty(
     help=("Use a specific output format"),
     show_default=True,
 )
+@click.option(
+    "--stdin-filepath",
+    type=click.Path(
+        exists=False,
+        file_okay=True,
+        dir_okay=False,
+        readable=False,
+        allow_dash=False,
+    ),
+    help=("Path to the file to pretend that stdin comes from."),
+)
 @click.option(
     "--include",
     type=str,
@@ -94,6 +113,15 @@ def path_empty(
     ),
     show_default=True,
 )
+@click.option(
+    "--rule",
+    type=RULE,
+    help=(
+        'Specify rules, with the syntax --rule \'code: {"json": "value"}\'. '
+        "Can be provided multiple times to configure multiple rules."
+    ),
+    multiple=True,
+)
 @click.argument(
     "src",
     nargs=-1,
@@ -126,10 +154,13 @@ def main(
     verbose: bool,
     quiet: bool,
     parse_only: bool,
+    print_config: bool,
     config: Optional[str],
     format: str,
+    stdin_filepath: str,
     include: str,
     exclude: str,
+    rule: Union[Mapping[str, Any], Tuple[Mapping[str, Any], ...]],
     src: Tuple[str, ...],
 ) -> None:
     """Prototype linter for Jinja and Django templates, forked from jinjalint"""
@@ -171,7 +202,9 @@ def main(
                 )
             )
         elif p.is_file() or s == "-":
-            # if a file was explicitly given, we don't care about its extension
+            if verbose:
+                out("Analyzing file content from stdin")
+
             sources.add(p)
         else:
             err(f"invalid path: {s}")
@@ -187,14 +220,31 @@ def main(
         out("Files being analyzed:")
         out("\n".join(str(s) for s in sources), bold=False, fg="blue")
 
-    configuration = {}
+    configuration = {}  # type: Dict[str, Any]
     if ctx.default_map:
         configuration.update(ctx.default_map)
 
+    rules = configuration.get("rules", {})
+
+    if rule:
+        if isinstance(rule, tuple):
+            for r in rule:
+                rules.update(r)
+        else:
+            rules.update(rule)
+
+    configuration["rules"] = rules
     configuration["verbose"] = verbose
     configuration["parse_only"] = parse_only
 
-    issues = lint(sources, configuration)
+    if stdin_filepath:
+        configuration["stdin_filepath"] = Path(stdin_filepath)
+
+    if len(sources) == 1:
+        issues = lint_one(sources.pop(), configuration)
+    else:
+        issues = lint(sources, configuration)
+
     report.print_issues(issues)
 
     if verbose or not quiet:
